part of nodejs_interop;

/// Completes a [Promise] with a value or an error.
typedef void PromiseCompleter<T>(void resolve(T value), void reject(error));

/// An object representing a delayed computation.
///
/// A [Promise] is used to represent a potential value, or error, that will be available at some time in the future.
/// Receivers of a [Promise] can register callbacks that handle the value or error once it is available.
@JS('Promise')
abstract class Promise<T> {

  /// Creates a new promise.
  external factory Promise(PromiseCompleter<T> completer);

  /// Returns a [Promise] that is rejected with the given [error].
  external static Promise reject(error);

  /// Returns a [Promise] that is resolved with the given [value].
  external static Promise<T> resolve<T>(T value);

  /// Registers callbacks to be called when this promise completes.
  external Promise<V> then<V>(V onFulfilled(T value), [V onRejected(error)]);
}
