part of nodejs_interop;

/// A generic JavaScript error.
@JS('Error')
abstract class JsError implements Exception {

  /// Creates a new error.
  external factory JsError([String message]);

  /// The number of stack frames collected by a stack trace. Defaults to `10`.
  external static int get stackTraceLimit;
  external static set stackTraceLimit(int value);

  /// A label that identifies the kind of error.
  external String get code;
  external set code(String value);

  /// The description of the error.
  external String get message;
  external set message(String value);

  /// A name for the type of error. Defaults to `"Error"`.
  external String get name;
  external set name(String value);

  /// A string describing the point in the code at which the [JsError] was instantiated.
  external String get stack;

  /// Creates a [stack] property on [targetObject],
  /// which when accessed returns a string representing the location in the code at which [captureStackTrace] was called.
  external void captureStackTrace(targetObject, [JsFunction constructorOpt]);
}

/// Indicates that a program is not valid JavaScript.
/// These errors may only be generated and propagated as a result of code evaluation.
@JS('EvalError')
abstract class JsEvalError extends JsError {

  /// Creates a new syntax error.
  external factory JsEvalError([String message]);
}

/// Indicates that a provided argument was not within the set or range of acceptable values for a function;
/// whether that is a numeric range, or outside the set of options for a given function parameter.
@JS('RangeError')
abstract class JsRangeError extends JsError {

  /// Creates a new range error.
  external factory JsRangeError([String message]);
}

/// Indicates that an attempt is being made to access a variable that is not defined.
/// Such errors commonly indicate typos in code, or an otherwise broken program.
@JS('ReferenceError')
abstract class JsReferenceError extends JsError {

  /// Creates a new reference error.
  external factory JsReferenceError([String message]);
}

/// Indicates that a program is not valid JavaScript.
/// These errors may only be generated and propagated as a result of code evaluation.
@JS('SyntaxError')
abstract class JsSyntaxError extends JsError {

  /// Creates a new syntax error.
  external factory JsSyntaxError([String message]);
}

/// Indicates that a provided argument is not an allowable type.
/// For example, passing a function to a parameter which expects a string would be considered a [TypeError].
@JS('TypeError')
abstract class JsTypeError extends JsError {

  /// Creates a new type error.
  external factory JsTypeError([String message]);
}

/// Indicates that a provided argument is not an allowable type.
/// For example, passing a function to a parameter which expects a string would be considered a [TypeError].
@JS('URIError')
abstract class JsUriError extends JsError {

  /// Creates a new type error.
  external factory JsUriError([String message]);
}
