part of nodejs_interop;

/// The [`assert`](https://nodejs.org/api/assert.html) module.
@JS(r'$assert')
abstract class AssertModule {

  /// Tests for deep equality between the [actual] and [expected] parameters.
  external void deepEqual(actual, expected, [String message]);

  /// Tests for deep strict equality between the [actual] and [expected] parameters.
  external void deepStrictEqual(actual, expected, [String message]);

  /// Asserts that the function [block] does not throw an [error].
  external void doesNotThrow(Function block, [error, String message]);

  /// Tests shallow, coercive equality between the [actual] and [expected] parameters using the abstract equality comparison (`==`).
  external void equal(actual, expected, [String message]);

  /// Throws an assertion error.
  external void fail([actualOrMessage, expected, String message, String operator, JsFunction stackStartFunction]);

  /// Throws [value] if [value] is truthy. This is useful when testing the `error` argument in callbacks.
  external void ifError(value);

  /// Tests for any deep inequality. Opposite of [deepEqual].
  external void notDeepEqual(actual, expected, [String message]);

  /// Tests for deep strict inequality. Opposite of [deepStrictEqual].
  external void notDeepStrictEqual(actual, expected, [String message]);

  /// Tests shallow, coercive inequality with the abstract equality comparison (`!=`).
  external void notEqual(actual, expected, [String message]);

  /// Tests strict inequality as determined by the strict equality comparison (`!==`).
  external void notStrictEqual(actual, expected, [String message]);

  /// Tests if [value] is truthy.
  external void ok(value, [String message]);

  /// Tests strict equality as determined by the strict equality comparison (`===`).
  external void strictEqual(actual, expected, [String message]);

  /// Expects the function [block] to throw an [error].
  external void throws(Function block, [error, String message]);
}
