part of nodejs_interop;

/// Provides information about, and control over, the current Node.js process.
@JS()
abstract class Process extends EventEmitter {

  /// Creates a process.
  external factory Process._();

  /// The processor architecture that the Node.js process is currently running on.
  external String get arch;

  /// The command line arguments passed when the Node.js process was launched.
  ///
  /// The first element will be [execPath]. See [argv0] if access to the original value of `argv[0]` is needed.
  /// The second element will be the path to the JavaScript file being executed.
  /// The remaining elements will be any additional command line arguments.
  external List<String> get argv;

  /// The the original value of `argv[0]` passed when Node.js starts.
  external String get argv0;

  /// If the Node.js process is spawned with an IPC channel, the [connected] property will return `true` so long as the IPC channel is connected.
  /// It will return `false` after [disconnect] is called.
  external bool get connected;

  /// An object containing the user environment.
  external _JsObject get env;

  /// The list of Node.js-specific command-line options passed when the Node.js process was launched.
  ///
  /// These options do not appear in the array returned by the [argv] property, and do not include the Node.js executable,
  /// the name of the script, or any options following the script name.
  /// These options are useful in order to spawn child processes with the same execution environment as the parent.
  external List<String> get execArgv;

  /// The absolute pathname of the executable that started the Node.js process.
  external String get execPath;

  /// The PID of the process.
  external int get pid;

  /// A string identifying the operating system platform on which the Node.js process is running.
  external String get platform;

  /// The Node.js version string.
  external String get version;

  /// Causes the Node.js process to exit immediately and generate a core file.
  external void abort();

  /// Returns the current working directory of the Node.js process.
  external String cwd();

  /// Changes the current working [directory] of the Node.js process.
  external void chdir(String directory);

  /// Returns the user and system CPU time usage of the current process.
  /// The result of a previous call to [cpuUsage] can be passed as the argument to the function, to get a diff reading.
  external CpuUsage cpuUsage([CpuUsage previousValue]);

  /// If the Node.js process is spawned with an IPC channel, the method will close the IPC channel to the parent process,
  /// allowing the child process to exit gracefully once there are no other connections keeping it alive.
  ///
  /// The effect of calling [disconnect] is that same as calling the parent process's [ChildProcess.disconnect].
  external void disconnect();

  /// Returns the numeric user identity of the process.
  external int getuid();
}
