part of nodejs_interop;

/// The [`os`](https://nodejs.org/api/os.html) module.
@JS(r'$os')
abstract class OsModule {

  /// Commonly used operating system specific constants for error codes, process signals, and so on.
  external OsConstants get constants;

  /// The operating system-specific end-of-line marker.
  /// This is `"\r\n"` on Windows and `"\r"` on other platforms.
  external String get EOL;

  /// Returns a string identifying the operating system CPU architecture for which the Node.js binary was compiled.
  /// Equivalent to [Process.arch].
  external String arch();

  /// Returns a list of objects containing information about each logical CPU core.
  external List<Cpu> cpus();

  /// Returns a string identifying the endianness of the CPU for which the Node.js binary was compiled.
  external String endianness();

  /// Returns the amount of free system memory in bytes.
  external int freemem();

  /// Returns the home directory of the current user.
  external String homedir();

  /// Returns the hostname of the operating system.
  external String hostname();

  /// Returns a list containing the 1, 5, and 15 minute load averages.
  external List<double> loadavg();

  /// Returns an object containing only network interfaces that have been assigned a network address.
  external _JsObject networkInterfaces();

  /// Returns a string identifying the operating system platform as set during compile time of Node.js.
  external String platform();

  /// The operating system release.
  external String release();

  /// The operating system's default directory for temporary files.
  external String tmpdir();

  /// The total amount of system memory in bytes.
  external int totalmem();

  /// The operating system name.
  external String type();

  /// The system uptime in number of seconds.
  /// On Windows the returned value includes fractions of a second. Use [num.floor] to get whole seconds.
  external num uptime();

  /// Returns information about the currently effective user.
  ///
  /// The returned object includes the `username`, `uid`, `gid`, `shell`, and `homedir`.
  /// On POSIX platforms, this is typically a subset of the password file.
  /// On Windows, the `uid` and `gid` fields are `-1`, and `shell` is null.
  external UserInfo userInfo([/* TODO StreamOptions */ options]);
}
