import 'dart:js';
import 'package:nodejs_interop/nodejs_interop.dart';
import 'package:test/test.dart';

/// Returns a list of a given [object]'s own enumerable properties.
List<String> getKeysOfObject(JsObject object) => (context['Object'] as JsFunction).callMethod('keys', [object]);

/// Tests the features of the `NodejsPlatform` class.
void main() => group('NodejsPlatform', () {
  final isMacOS = context['process']['platform'] == 'darwin';
  final isWindows = context['process']['platform'] == 'win32';

  group('.environment', () {
    var env = const NodejsPlatform().environment;
    var jsEnv = context['process']['env'] as JsObject;

    test('should reflect the values of the `process.env` property', () {
      var keys = getKeysOfObject(jsEnv).where((key) => !key.contains('__dart__'));
      expect(env.length, equals(keys.length));
      for (var key in keys) expect(env[key], equals(jsEnv[key]), reason: key);
    });

    test('should be an unmodifiable map', () {
      expect(() => env['Foo'] = 'Bar', throwsUnsupportedError);
    });

    test('should be case-insensitive on Windows, case-sensitive on other platforms', () {
      expect(env['home'], isWindows ? isNotEmpty : isNull);
    });
  });

  group('.executable', () {
    test('should be `node.exe` on Windows and `node` on other platforms', () {
      expect(const NodejsPlatform().executable, endsWith(isWindows ? 'node.exe' : 'node'));
    });
  });

  group('.operatingSystem', () {
    test('should be `macos` on macOS, `windows` on Windows and `linux` on other platforms', () {
      expect(const NodejsPlatform().operatingSystem, endsWith(isWindows ? 'windows' : (isMacOS ? 'macos' : 'linux')));
    });
  });

  group('.pathSeparator', () {
    test('should be `\\` on Windows and `/` on other platforms', () {
      expect(const NodejsPlatform().pathSeparator, equals(isWindows ? r'\' : '/'));
    });
  });

  group('.resolvedExecutable', () {
    test('should be the absolute path to `node.exe` on Windows and `node` on other platforms', () {
      expect(const NodejsPlatform().resolvedExecutable, endsWith(isWindows ? r'\node.exe' : '/node'));
    });
  });

  group('.version', () {
    test('should be a SemVer string representing the `process.version` property', () {
      expect(const NodejsPlatform().version, equals(context['process']['version'].substring(1)));
    });
  });
});
